" Vim ftplugin file
" Language:     Leex (Erlang Lexical Analyzer Generator)
" Maintainer:   Jon Parise <jon@indelible.org>
" Last Change:  2025 Nov 29
" Filenames:    *.xrl
"
" References:
" - https://www.erlang.org/doc/apps/parsetools/leex.html

if exists('b:did_ftplugin')
  finish
endif

runtime! ftplugin/erlang.vim
